==> ff-global-2.0.41.tgz: package/common/ajax.ts <==
import axios, {AxiosError, AxiosInstance, AxiosRequestConfig, AxiosResponse, Canceler} from 'axios'
import Env from './env'

const localMsg = {
  请求超时: 'The request timeout',
  网络错误: 'Network Error',
  服务器555错误: 'Server  error',
  服务器500错误: 'Server 500 error',
  接口不存在: 'Interface does not exist',
  请求发生错误: 'Request error',
  请求实体太大: 'Request Entity Too Large'
}

declare global {
  interface Promise<T> {
    abort?: Canceler
  }
}

class Ajax {
  instance: AxiosInstance //缺省实例
  longTimeInstance: AxiosInstance //超长请求实例
  codeErrorCb?: (errorCode: number, msg: string) => void //如果有错误，错误代码回调
  constructor(baseURL?: string) {
    let opt: AxiosRequestConfig = {
      baseURL: baseURL ?? Env.config.baseApi,
      timeout: 120000,
      withCredentials: true,
      headers: {
        'accept-language': 'zh,zh-TW;q=0.9,en-US;q=0.8,en;q=0.7,zh-CN;q=0.6'
      }
    }
    this.instance = axios.create(opt)
    this.longTimeInstance = axios.create({...opt, timeout: 300000}) //请求超时,
  }

  get(url: string, data = {}, header = {}) {
    let CancelToken = axios.CancelToken
    let cancel = undefined
    let conf = {
      params: data,
      headers: header,
      cancelToken: new CancelToken(c => {
        cancel = c
      })
    }

    let res = this.instance.get(url, conf).then(this.dispose.bind(this)).catch(this.error)

    res.abort = cancel
    return res
  }

  onCodeError(cb: (errorCode: number, msg: string) => void) {
    this.codeErrorCb = cb
  }

  downblob(url: string, data = {}) {
    return this.instance({
      method: 'post',
      responseType: 'blob',
      url: url,
      data: data
    })
      .then(res => {
        return new Promise((resolve, reject) => {
          if (res.data.type === 'text/json' || res.data.type === 'application/json') {
            let fr = new FileReader()
            fr.readAsText(res.data)
            let _this = this
            fr.onload = function () {
              if (typeof this.result === 'string') {
                let j = JSON.parse(this.result)
                _this.dispose({status: 200, data: j}).catch(e => {
                  reject(e)
                })
              }
            }
          } else {
            const url = window.URL.createObjectURL(new Blob([res.data]))
            const link = document.createElement('a')
            let regr = /filename= "(.*?)"/.exec(res.headers['content-disposition'])

            let name = regr ? decodeURI(regr[1]) : ''

            link.href = url
            link.setAttribute('download', `${name}`)
            document.body.appendChild(link)
            link.click()
            setTimeout(() => {
              document.body.removeChild(link)
            }, 1000)

            resolve(null)
          }
        })
      })
      .catch(e => {
        return Promise.reject(e)
      })
  }

  //@param islong 是否可以请时间请求，如发送email时可能需要很久时间；
  post(url: string, data = {}, headers = {}, islong?: boolean) {
    let CancelToken = axios.CancelToken
    let cancel = undefined

    let conf = {headers: headers}
    let req = islong ? this.longTimeInstance : this.instance
    let res = req({
      method: 'post',
      url: url,
      data: data,
      cancelToken: new CancelToken(c => {
        // An executor function receives a cancel function as a parameter
        cancel = c
      }),
      ...conf
    })
      .then(this.dispose.bind(this))
      .catch(this.error)

    res.abort = cancel
    return res
  }

  //响应处理
  dispose(res: AxiosResponse | {status: 200; data: any}) {
    if (res.status !== 200 || !res.data) {
      return Promise.reject({msg: localMsg['请求发生错误'], code: res.status})
    }

    let data = res.data
    if (!data.hasOwnProperty('code')) {
      return Promise.resolve(data)
    }
    if (data.code !== 0) {
      if (this.codeErrorCb) {
        this.codeErrorCb(data.code, data.msg)
      }

      return Promise.reject(data)
    } else {
      return Promise.resolve(data.data)
    }
  }

  //错误处理
  //@param err { Error|string|Object{code(int),msg(string)} } 错误内容
  error(err: any) {
    console.log('ajax error ', err instanceof Error, typeof err, [err])
    console.warn(err)

    if (<AxiosError>err instanceof Error) {

      if(err.code && err.code ==='ERR_CANCELED'){
        //用户手动取消操作
        throw ff.error('abort_error')
      }

      if (err.response) {
        if (err.response.status === 404) {
          throw {msg: localMsg['接口不存在'], code: 4000}
        } else if (err.response.status >= 500) {
          throw {msg: localMsg['服务器500错误'], code: 500}
        } else {
          throw {msg: err.response.statusText, code: err.response.status}
        }
      }

      if (err.request && err.request.status === 0) {
        console.log(err.toString())
        //            console.log(err.request)
        Object.keys(err).forEach(val => {
          console.log(val)
          console.log(err[val])
        })
        if (err.toString() === 'Error: Network Error') {
          throw {msg: localMsg['网络错误'], code: 4000}
        }
        throw {msg: localMsg['请求超时'], code: 4000}
      }

      throw {msg: localMsg['服务器555错误'], code: 555}
    } else if (typeof err === 'object') {
      if (err.__CANCEL__) {
        //用户手动取消操作
        throw ff.error('abort_error')
      } else if (err.code) {
        return Promise.reject(err)
      }
    } else if (typeof err === 'string') {
      throw {msg: err, code: 500}
    } else {
      throw {msg: err, code: 500}
    }
  }
}

export default Ajax

==> ff-global-3.0.0.tgz: package/common/ajax.ts <==
import axios, {AxiosError, AxiosInstance, AxiosRequestConfig, AxiosResponse, Canceler} from 'axios'
import Env from './env'

const localMsg = {
  请求超时: 'The request timeout',
  网络错误: 'Network Error',
  服务器555错误: 'Server  error',
  服务器500错误: 'Server 500 error',
  接口不存在: 'Interface does not exist',
  请求发生错误: 'Request error',
  请求实体太大: 'Request Entity Too Large'
}

declare global {
  interface Promise<T> {
    abort?: Canceler
  }
}

class Ajax {
  instance: AxiosInstance //缺省实例
  longTimeInstance: AxiosInstance //超长请求实例
  codeErrorCb?: (errorCode: number, msg: string) => void //如果有错误，错误代码回调
  constructor(baseURL?: string) {
    let opt: AxiosRequestConfig = {
      baseURL: baseURL ?? Env.config.baseApi,
      timeout: 120000,
      withCredentials: true,
      headers: {
        'accept-language': 'zh,zh-TW;q=0.9,en-US;q=0.8,en;q=0.7,zh-CN;q=0.6'
      }
    }
    this.instance = axios.create(opt)
    this.longTimeInstance = axios.create({...opt, timeout: 300000}) //请求超时,
  }

  get(url: string, data = {}, header = {}) {
    let CancelToken = axios.CancelToken
    let cancel = undefined
    let conf = {
      params: data,
      headers: header,
      cancelToken: new CancelToken(c => {
        cancel = c
      })
    }

    let res = this.instance.get(url, conf).then(this.dispose.bind(this)).catch(this.error)

    res.abort = cancel
    return res
  }

  onCodeError(cb: (errorCode: number, msg: string) => void) {
    this.codeErrorCb = cb
  }

  downblob(url: string, data = {}) {
    return this.instance({
      method: 'post',
      responseType: 'blob',
      url: url,
      data: data
    })
      .then(res => {
        return new Promise((resolve, reject) => {
          if (res.data.type === 'text/json' || res.data.type === 'application/json') {
            let fr = new FileReader()
            fr.readAsText(res.data)
            let _this = this
            fr.onload = function () {
              if (typeof this.result === 'string') {
                let j = JSON.parse(this.result)
                _this.dispose({status: 200, data: j}).catch(e => {
                  reject(e)
                })
              }
            }
          } else {
            const url = window.URL.createObjectURL(new Blob([res.data]))
            const link = document.createElement('a')
            let regr = /filename= "(.*?)"/.exec(res.headers['content-disposition'])

            let name = regr ? decodeURI(regr[1]) : ''

            link.href = url
            link.setAttribute('download', `${name}`)
            document.body.appendChild(link)
            link.click()
            setTimeout(() => {
              document.body.removeChild(link)
            }, 1000)

            resolve(null)
          }
        })
      })
      .catch(e => {
        return Promise.reject(e)
      })
  }

  //@param islong 是否可以请时间请求，如发送email时可能需要很久时间；
  post(url: string, data = {}, headers = {}, islong?: boolean) {
    let CancelToken = axios.CancelToken
    let cancel = undefined

    let conf = {headers: headers}
    let req = islong ? this.longTimeInstance : this.instance
    let res = req({
      method: 'post',
      url: url,
      data: data,
      cancelToken: new CancelToken(c => {
        // An executor function receives a cancel function as a parameter
        cancel = c
      }),
      ...conf
    })
      .then(this.dispose.bind(this))
      .catch(this.error)

    res.abort = cancel
    return res
  }

  //响应处理
  dispose(res: AxiosResponse | {status: 200; data: any}) {
    if (res.status !== 200 || !res.data) {
      return Promise.reject({msg: localMsg['请求发生错误'], code: res.status})
    }

    let data = res.data
    if (!data.hasOwnProperty('code')) {
      return Promise.resolve(data)
    }
    if (data.code !== 0) {
      if (this.codeErrorCb) {
        this.codeErrorCb(data.code, data.msg)
      }

      return Promise.reject(data)
    } else {
      return Promise.resolve(data.data)
    }
  }

  //错误处理
  //@param err { Error|string|Object{code(int),msg(string)} } 错误内容
  error(err: any) {
    console.log('ajax error ', err instanceof Error, typeof err, [err])
    console.warn(err)

    if (<AxiosError>err instanceof Error) {

      if(err.code){
        if(err.code ==='ERR_CANCELED'){
          //用户手动取消操作
          throw ff.error('abort_error')
        }else if(err.code === "ERR_NETWORK"){
          throw {msg: localMsg['请求超时'], code: 4000}
        }

      }

      if (err.response) {
        if (err.response.status === 404) {
          throw {msg: localMsg['接口不存在'], code: 4000}
        } else if (err.response.status >= 500) {
          throw {msg: localMsg['服务器500错误'], code: 500}
        } else {
          throw {msg: err.response.statusText|| err.message, code: err.response.status|| 600}
        }
      }

      if (err.request && err.request.status === 0) {
        console.log(err.toString())
        //            console.log(err.request)
        Object.keys(err).forEach(val => {
          console.log(val)
          console.log(err[val])
        })
        if (err.toString() === 'Error: Network Error') {
          throw {msg: localMsg['网络错误'], code: 4000}
        }
        throw {msg: localMsg['请求超时'], code: 4000}
      }

      throw {msg: localMsg['服务器555错误'], code: 555}
    } else if (typeof err === 'object') {
      if (err.__CANCEL__) {
        //用户手动取消操作
        throw ff.error('abort_error')
      } else if (err.code) {
        return Promise.reject(err)
      }
    } else if (typeof err === 'string') {
      throw {msg: err, code: 500}
    } else {
      throw {msg: err, code: 500}
    }
  }
}

export default Ajax
